@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -291,11 +291,12 @@ public class SproxydFileStorageFactory implements FileStorageProvider, Interests
         String hosts = requireProperty(filestoreID, "hosts", nameBuilder, configService);
 
         int heartbeatInterval = optIntProperty(filestoreID, "heartbeatInterval", 60000, nameBuilder, configService);
+        boolean blacklistEndpoints = PropertyNameBuilder.optBoolProperty(filestoreID, "blockEndpoints", true, nameBuilder, configService);
 
         List<String> urls = new LinkedList<String>();
         for (String host : Strings.splitAndTrim(hosts, ",")) {
             URIBuilder uriBuilder = new URIBuilder().setScheme(protocol);
-            String[] hostAndPort = host.split(":");
+            String[] hostAndPort = Strings.splitByColon(host);
             if (hostAndPort.length == 1) {
                 uriBuilder.setHost(host);
             } else if (hostAndPort.length == 2) {
@@ -324,7 +325,7 @@ public class SproxydFileStorageFactory implements FileStorageProvider, Interests
             throw ConfigurationExceptionCodes.INVALID_CONFIGURATION.create("Invalid value for 'com.openexchange.filestore.sproxyd." + filestoreID + ".hosts': " + hosts);
         }
 
-        return new EndpointPool(filestoreID, urls, heartbeatInterval, services);
+        return new EndpointPool(filestoreID, urls, heartbeatInterval, blacklistEndpoints, services);
     }
 
     /**
