@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -42,10 +42,12 @@ import com.openexchange.server.ServiceLookup;
  */
 public class SproxydHttpClientConfig extends AbstractHttpClientModifer implements WildcardHttpClientConfigProvider {
 
-    private static final String HTTP_CLIENT_IDENTIFIER = "sproxyd";
-    
+    /** The identifier for sproxyd clients */
+    public static final String HTTP_CLIENT_IDENTIFIER = "sproxyd";
+
     private static final int DEF_READ_TIMEOUT = 15000;
     private static final int DEF_CON_TIMEOUT = 5000;
+    private static final int DEF_CON_LEASE_TIMEOUT = 5000;
     private static final int DEF_MAX_CONNECTIONS_PER_HOST = 100;
     private static final int DEF_MAX_CONNECTIONS = 100;
 
@@ -65,7 +67,7 @@ public class SproxydHttpClientConfig extends AbstractHttpClientModifer implement
     public @NonNull String getClientIdPattern() {
         return HTTP_CLIENT_IDENTIFIER + "*";
     }
-    
+
     @Override
     @NonNull
     public String getGroupName() {
@@ -100,11 +102,24 @@ public class SproxydHttpClientConfig extends AbstractHttpClientModifer implement
         PropertyNameBuilder nameBuilder = new PropertyNameBuilder("com.openexchange.filestore.sproxyd.");
         ConfigurationService configService = serviceLookup.getServiceSafe(ConfigurationService.class);
 
-        config.setMaxTotalConnections(optIntProperty(clientId, "maxConnections", DEF_MAX_CONNECTIONS, nameBuilder, configService));
-        config.setMaxConnectionsPerRoute(optIntProperty(clientId, "maxConnectionsPerHost", DEF_MAX_CONNECTIONS_PER_HOST, nameBuilder, configService));
-        config.setConnectTimeout(optIntProperty(clientId, "connectionTimeout", DEF_CON_TIMEOUT, nameBuilder, configService));
-        config.setSocketReadTimeout(optIntProperty(clientId, "socketReadTimeout", DEF_READ_TIMEOUT, nameBuilder, configService));
+        String filestoreId = getFilestoreId(clientId);
+        config.setMaxTotalConnections(optIntProperty(filestoreId, "maxConnections", DEF_MAX_CONNECTIONS, nameBuilder, configService));
+        config.setMaxConnectionsPerRoute(optIntProperty(filestoreId, "maxConnectionsPerHost", DEF_MAX_CONNECTIONS_PER_HOST, nameBuilder, configService));
+        config.setConnectTimeout(optIntProperty(filestoreId, "connectionTimeout", DEF_CON_TIMEOUT, nameBuilder, configService));
+        config.setSocketReadTimeout(optIntProperty(filestoreId, "socketReadTimeout", DEF_READ_TIMEOUT, nameBuilder, configService));
+        config.setConnectionRequestTimeout(optIntProperty(filestoreId, "connectionLeaseTimeout", DEF_CON_LEASE_TIMEOUT, nameBuilder, configService));
         return config;
     }
 
+    private String getFilestoreId(String filestoreId) {
+        if (false == filestoreId.startsWith(HTTP_CLIENT_IDENTIFIER)) {
+            return filestoreId;
+        }
+        String id = filestoreId.substring(HTTP_CLIENT_IDENTIFIER.length());
+        if (id.startsWith(".")) {
+            return id.substring(1);
+        }
+        return id;
+    }
+
 }
