@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -21,6 +21,7 @@
 
 package com.openexchange.filestore.sproxyd.impl;
 
+import static com.openexchange.filestore.sproxyd.http.SproxydHttpClientConfig.HTTP_CLIENT_IDENTIFIER;
 import static com.openexchange.java.Autoboxing.I;
 import java.util.ArrayList;
 import java.util.List;
@@ -65,6 +66,7 @@ public class EndpointPool {
     private final AtomicInteger counter;
     private final String filestoreId;
     private final int numberOfEndpoints;
+    private final boolean blacklistEndpoints;
     private final ServiceLookup services;
     private ScheduledTimerTask heartbeat;
 
@@ -74,12 +76,14 @@ public class EndpointPool {
      * @param filestoreId The filestore ID
      * @param endpointUrls A list of endpoint URLs to manage; must not be empty; URLs must always end with a trailing slash
      * @param heartbeatInterval
+     * @param blacklistEndpoints Whether to black-list end-points if considered as unavailable
      * @param services
      * @throws OXException
      */
-    public EndpointPool(String filestoreId, List<String> endpointUrls, int heartbeatInterval, ServiceLookup services) throws OXException {
+    public EndpointPool(String filestoreId, List<String> endpointUrls, int heartbeatInterval, boolean blacklistEndpoints, ServiceLookup services) throws OXException {
         super();
         this.filestoreId = filestoreId;
+        this.blacklistEndpoints = blacklistEndpoints;
         this.services = services;
         int size = endpointUrls.size();
         numberOfEndpoints = size;
@@ -136,10 +140,19 @@ public class EndpointPool {
     }
 
     /**
-     * Gets an available endpoint.
+     * Checks whether to black-list end-points if considered as unavailable.
+     *
+     * @return <code>true</code> for black-listing; otherwise <code>false</code>
+     */
+    public boolean isBlacklistEndpoints() {
+        return blacklistEndpoints;
+    }
+
+    /**
+     * Gets an available end-point.
      *
      * @param prefix The prefix
-     * @return The endpoint or <code>null</code> if all endpoints have been blacklisted
+     * @return The end-point or <code>null</code> if all end-points have been blacklisted
      */
     public Endpoint get(String prefix) {
         lock.readLock().lock();
@@ -163,11 +176,16 @@ public class EndpointPool {
     }
 
     /**
-     * Removes an endpoint from the list of available ones and adds it to the blacklist.
+     * Removes an end-point from the list of available ones and adds it to the blacklist.
      *
-     * @param url The base URL of the endpoint
+     * @param url The base URL of the end-point
      */
     public void blacklist(String url) {
+        if (!blacklistEndpoints) {
+            LOG.warn("Sproxyd endpoint pool [{}]: Endpoint {} is NOT added to blacklist since disabled via configuration", filestoreId, url);
+            return;
+        }
+
         lock.writeLock().lock();
         try {
             if (available.remove(url)) {
@@ -250,7 +268,8 @@ public class EndpointPool {
 
                 LOG.debug("Sproxyd endpoint pool [{}]: Heartbeat - blacklist contains {} endpoints", filestoreId, I(blacklist.size()));
                 for (String endpoint : blacklist) {
-                    HttpClient httpClient = services.getServiceSafe(HttpClientService.class).getHttpClient(filestoreId);
+                    String clientId = filestoreId.startsWith(HTTP_CLIENT_IDENTIFIER) ? filestoreId : HTTP_CLIENT_IDENTIFIER + "." + filestoreId;
+                    HttpClient httpClient = services.getServiceSafe(HttpClientService.class).getHttpClient(clientId);
                     if (Utils.endpointUnavailable(endpoint, httpClient)) {
                         LOG.warn("Sproxyd endpoint pool [{}]: Endpoint {} is still unavailable", filestoreId, endpoint);
                     } else {
