@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -38,6 +38,7 @@ import org.apache.http.entity.InputStreamEntity;
 import com.openexchange.exception.OXException;
 import com.openexchange.filestore.FileStorageCodes;
 import com.openexchange.filestore.sproxyd.SproxydExceptionCode;
+import com.openexchange.filestore.sproxyd.http.SproxydHttpClientConfig;
 import com.openexchange.java.util.UUIDs;
 import com.openexchange.rest.client.httpclient.HttpClientService;
 import com.openexchange.rest.client.httpclient.HttpClients;
@@ -292,7 +293,7 @@ public class SproxydClient {
             return FileStorageCodes.IOERROR.create(e, e.getMessage());
         }
 
-        if (Utils.endpointUnavailable(endpoint.getBaseUrl(), getHttpClient())) {
+        if (endpointPool.isBlacklistEndpoints() && Utils.endpointUnavailable(endpoint.getBaseUrl(), getHttpClient())) {
             LOG.warn("Sproxyd endpoint is unavailable: {}", endpoint);
             endpointPool.blacklist(endpoint.getBaseUrl());
         }
@@ -307,6 +308,9 @@ public class SproxydClient {
      * @throws OXException If HTTP client cannot be returned
      */
     HttpClient getHttpClient() throws OXException {
+        if (false == filestoreID.startsWith(SproxydHttpClientConfig.HTTP_CLIENT_IDENTIFIER)) {
+            return services.getServiceSafe(HttpClientService.class).getHttpClient(SproxydHttpClientConfig.HTTP_CLIENT_IDENTIFIER + "." + filestoreID);
+        }
         return services.getServiceSafe(HttpClientService.class).getHttpClient(filestoreID);
     }
 
