@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -24,6 +24,7 @@ package com.openexchange.filestore.sproxyd.osgi;
 import java.rmi.Remote;
 import java.util.Dictionary;
 import java.util.Hashtable;
+import com.openexchange.auth.Authenticator;
 import com.openexchange.config.ConfigurationService;
 import com.openexchange.context.ContextService;
 import com.openexchange.database.CreateTableService;
@@ -64,6 +65,11 @@ public class SproxydActivator extends HousekeepingActivator {
         return new Class<?>[] { ConfigurationService.class, DatabaseService.class, TimerService.class, HttpClientService.class };
     }
 
+    @Override
+    protected Class<?>[] getOptionalServices() {
+        return new Class[] { Authenticator.class };
+    }
+
     @Override
     protected void startBundle() throws Exception {
         LOG.info("Starting bundle: com.openexchange.filestore.sproxyd");
